#
# spec file for package perl-Spreadsheet-Read
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Spreadsheet-Read
Name:           perl-Spreadsheet-Read
Version:        0.900.0
Release:        2.3
%define cpan_version 0.90
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Meta-Wrapper for reading spreadsheet data
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/H/HM/HMBRAND/%{cpan_name}-%{cpan_version}.tgz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Data::Peek)
BuildRequires:  perl(File::Temp) >= 0.22
BuildRequires:  perl(IO::Scalar)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::NoWarnings)
Requires:       perl(Data::Peek)
Requires:       perl(File::Temp) >= 0.22
Requires:       perl(IO::Scalar)
Requires:       perl(Test::More) >= 0.88
Requires:       perl(Test::NoWarnings)
Provides:       perl(Spreadsheet::Read) = %{version}
%undefine       __perllib_provides
Recommends:     perl(Data::Dumper) >= 2.183
Recommends:     perl(Data::Peek) >= 0.52
Recommends:     perl(Encode) >= 3.200.0
Recommends:     perl(File::Temp) >= 0.2311
Recommends:     perl(IO::Scalar)
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  perl(Spreadsheet::ParseExcel) >= 0.34
BuildRequires:  perl(Spreadsheet::ParseExcel::FmtDefault)
BuildRequires:  perl(Spreadsheet::ParseXLSX) >= 0.24
BuildRequires:  perl(Text::CSV_XS) >= 0.71
Recommends:     perl(Spreadsheet::ReadSXC) >= 0.20
Suggests:       perl-Spreadsheet-Read-scripts = %{version}
# MANUAL END

%description
Spreadsheet::Read tries to transparently read *any* spreadsheet and return
its content in a universal manner independent of the parsing module that
does the actual spreadsheet scanning.

For OpenOffice this module uses Spreadsheet::ReadSXC

For Microsoft Excel this module uses Spreadsheet::ParseExcel or
Spreadsheet::XLSX

For CSV this module uses Text::CSV_XS (0.29 or up required, 0.73 or up
preferred) or Text::CSV_PP (1.05 or up required).

For SquirrelCalc there is a very simplistic built-in parser

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
# MANUAL BEGIN
# Remove xls2csv and xls2csv.1 (conflict with libxls-tools and xls2csv packages)
rm -f %{buildroot}%{_bindir}/xls2csv
rm -f %{buildroot}%{_mandir}/man1/xls2csv.1
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md examples README
%exclude %{_bindir}/*
%exclude %{_mandir}/*

%package scripts
Summary:        Scripts to Work with Spreadsheets
Requires:       perl(HTML::Entities)
Requires:       perl(Spreadsheet::Read) = %{version}
Requires:       perl(Term::ReadKey)
Requires:       perl(Text::CSV_XS)
Requires:       perl(Tk)
Requires:       perl(Tk::TableMatrix::Spreadsheet)
# Conflict with ssdiff
Conflicts:      gnumeric

%description scripts
This package includes some scripts to work with spreadsheets.

%files scripts
%{_bindir}/ss2tk
%{_bindir}/ssdiff
%{_bindir}/xlscat
%{_bindir}/xlsgrep
%{_bindir}/xlsx2csv
%{_mandir}/man1/xlsx2csv.1%{?ext_man}

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Wed Feb 14 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.90
  see /usr/share/doc/packages/perl-Spreadsheet-Read/Changes
  0.90	- 13 Feb 2024, H.Merijn Brand
  * Consistent return value for parses ($type) on failure (issue#52)
  * New options for xlscat (--no-empty, --clip=N)
  * Support for hidden sheets
* Wed Jan  3 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.89
  see /usr/share/doc/packages/perl-Spreadsheet-Read/Changes
  0.89	- 02 Jan 2024, H.Merijn Brand
  * Auto-use BOM in CSV *files* with xlscat script
  * Fix duplicate option letter (typo) (Erix)
  * It's 2024
* Wed Nov  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.88
  see /usr/share/doc/packages/perl-Spreadsheet-Read/Changes
  0.88	- 07 Nov 2023, H.Merijn Brand
  * Guard $_ globbering from external bitrotted code
  * Use recommended and suggested versions based on known CVEs
  * Improve user feedback on failing xlsx2csv & xlscat
  * Fix static docs for groff-1.24
  * Basic support for Excel::ValueReader::XLSX (issue#50)
  * Allow backend for parser option without version check
* Thu Mar  9 2023 Tina Müller <tina.mueller@suse.com>
- Remove nonstdperlpath.patch, fixed paths upstream, thanks Tux :)
* Thu Feb 23 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.87
  see /usr/share/doc/packages/perl-Spreadsheet-Read/Changes
  0.87	- 22 Feb 2023, H.Merijn Brand
  * Change default #! to /usr/bin/perl (Tinita)
  * Improve ->sheets (safer and docs)
  * Update to Spreadsheet::ReadGnumeric 0.2 (attributes and small fixes)
  0.86	- 07 Feb 2023, H.Merijn Brand
  * Add Gnumeric support (Bob Rogers, THANKS!)
  - work in progress, use with care, feedback welcome
  0.85	- 04 Jan 2023, H.Merijn Brand
  * Suggest the preferred parser if none found
  * It's 2022
  * xlscat --box and improvements for -L
  * Add balloons to ss2tk buttons
  * Fix typo in help (Erix)
  * It's 2023
* Sat Jan 29 2022 Asterios Dramis <asterios.dramis@gmail.com>
- Do not install xls2csv and xls2csv.1 (conflict with libxls-tools
  and xls2csv packages).
* Mon Dec 27 2021 Asterios Dramis <asterios.dramis@gmail.com>
- Enabled installation of package examples and added them in a
  subpackage "scripts". Had to add also necessary Conflict entries
  with the following packages:
  gnumeric (Conflicts with ssdiff)
  xls2csv (Conflicts with xls2csv and xls2csv.1)
- Suggest new "scripts" subpackage in the main package.
* Tue Mar  2 2021 Tina Müller <tina.mueller@suse.com>
- Update nonstdperlpath.patch
* Sat Feb 27 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.84
  see /usr/share/doc/packages/perl-Spreadsheet-Read/Changes
  0.84	- 26 Feb 2021, H.Merijn Brand
  * It's 2021
  * Alias pivot to transpose (issue#36)
  * Alias strip to trim      (issue#36)
  * Check for consistent return values of parses ()
* Thu Jan 21 2021 Stephan Kulow <coolo@suse.com>
- readd hack to suppress examples in %%_bindir
* Tue Dec 22 2020 Tina Müller <tina.mueller@suse.com>
- Update patch nonstdperlpath.patch
* Tue Dec 22 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.83
  see /usr/share/doc/packages/perl-Spreadsheet-Read/Changes
  0.83	- 21 Dec 2020, H.Merijn Brand
  * Require ParseODS 0.26
  * Add ::parsers to get list of supported formats
  * Add --list to xlscat and xls2csv
  * Update xls2csv to be identical to xlsx2csv
  * ::parses ("") will return list of supported types
  * Move installables from examples/ to scripts/
  * Tested on FreeBSD-12.2-RELEASE with all supported backends
  * Fix META issue for bugtracker
* Sun Sep 27 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.82
  see /usr/share/doc/packages/perl-Spreadsheet-Read/Changes
  0.82	- 26 Sep 2020, H.Merijn Brand
  * Move pod tests to xt (and do not distribute)
  * Fix some links in the docs
  * Add ".xlsm" to known XLSX file extensions
  * Spreadsheet::ReadSXC has a new maintainer (Corion)
  - support file handles
  - suggest version 0.24 (0.22 causes fails)
  * First attempt in supporting Spreadsheet::ParseODS (alpha code)
  - version 0.25 should now pass the limited tests
  - thanks to Corion for making this happen!
  * It's 2020
  * Fallback to Pod::Text if nroff not available in tools
  * Extended support for merged cells with merge option
  - Added $sheet->merged_from ("C2")
  * Add --no-nl[=x] to xlscat
  * xlscat: Align-right more numerics on -L (was only positive integers)
  * xlsx2csv -Z : generate a ZIP file with a CSV for every sheet
  * Doc fix (issue#33)
* Fri Aug 30 2019 Tina Mueller <tina.mueller@suse.com>
- Add BuildRequires and Recommends because they are all optional
  but the module wouldn't make sense if none of those are installed
* Thu Aug 29 2019 Tina Mueller <tina.mueller@suse.com>
- Add patch nonstdperlpath.patch to the right place in cpanspec.yml and
  update spec
* Thu Aug 29 2019 <timueller+perl@suse.de>
- updated to 0.81
  see /usr/share/doc/packages/perl-Spreadsheet-Read/Changes
  0.81	- 25 Aug 2019, H.Merijn Brand
  * It's 2019
  * Allow -c + --sep in xlscat
  * Add --sep= to xls2csv for -A
  * Add xlsx2csv to distribution (xlsx2csv has -A)
  * Add -J s / --join str to xlsx2csv
  * Add cpanfile
  * Add explicit documentation about formatted vs unformatted
  * Improve ->new behavior
  * Auto-detect fallback for CSV now includes '|' for sep_char (PR#26)
* Tue Mar 19 2019 lars@linux-schulserver.de - 0.80
- update to 0.80
  * Raise Spreadsheet::ParseXLSX minimum version to 0.24
  * Improve docs on attributes
  * Add attribute accessors
- add BuildRequires for Spreadsheet::ParseExcel, Text::CSV_PP,
  Spreadsheet::ParseXLSX and Text::CSV_XS to run all tests
* Thu Sep 20 2018 coolo@suse.com
- updated to 0.79
  see /usr/share/doc/packages/perl-Spreadsheet-Read/
* Thu Feb  8 2018 coolo@suse.com
- updated to 0.78
  see /usr/share/doc/packages/perl-Spreadsheet-Read/
* Wed Jan  3 2018 stefan.bruens@rwth-aachen.de
- Resurrect description, the one from CPAN is insufficient
- Do not install examples to bin, conflicts with gnumeric and xls2csv
- Remove executable flags from all examples
* Wed Oct 18 2017 jamesp@vicidial.com
- nonstdperlpath.patch added
  * Change non-standard /pro/bin/perl path to /usr/bin/perl
* Sun Oct  8 2017 coolo@suse.com
- updated to 0.74
  see /usr/share/doc/packages/perl-Spreadsheet-Read/Changes
  0.74	- 27 Aug 2017, H.Merijn Brand
  * Re-enable opening files with bad characters in the filename (issue#14)
  0.73	- 30 Jul 2017, H.Merijn Brand
  * Spreadsheet::XLSX::Reader::LibXML support completely dropped
  * New options for ss2tk (font specs and SS labels)
  * Safer xls2csv option parsing/passing
  * Pass unknown command-line options to the parser
  * Fix ReadData ("a,b,c
  1,2,3
  ", parser => "csv")
  * Drop 5.8.0 support. 5.8.1 is now minimum
  0.72	- 25 May 2017, H.Merijn Brand
  * get_active_sheet is only available as of Spreadsheet::ParseExcel 0.61
  * Support password protected spreadsheets (implementation just for Excel)
  * Do not warn on undefined labels (xlscat)
  0.71	- 13 May 2017, H.Merijn Brand
  * Use -w as intended
  * Add option pivot
  * No trailing spaces on xlscat -L
  * Lexicalize code snippet (issue#12)
  * Add attr method
  * Remove special chars from worksheet name component (Windows, PR#13)
  * Add refresh to ss2tk / csv2tk
  * Add shortcut for UTF-8 output to xlscat
  * Upgrade recommended modules to required for cpancover
  0.70	- 02 Mar 2017, H.Merijn Brand
  * Add label functionality to ::Sheet
  * Add ->column and ->cellcolumn for ::Sheet
  * Add col2label sub/method
  * Sanitize xls2csv export filenames
  * Fix sorting in xlscat for un-aligned columns
  * It's 2017
  * Be overly verbose about maxrow and maxcol being 1-based (RT#120476)
  0.69	- 02 Dec 2016, H.Merijn Brand
  * Several OO fixes, more tests, more docs
  0.68	- 29 Nov 2016, H.Merijn Brand
  * List non-core modules/version used on very verbose in xlscat
  * Option to export all sheets in a spreadsheet to CSV (UTF-8 only)
  * Add OO interface
  * Feature: add new spreadsheets to existing book (even of different types)
  0.67	- 17 Jun 2016, H.Merijn Brand
  * CPANTESTERS showed that some versions really messed op numeric/percentage
  0.66	- 16 Jun 2016, H.Merijn Brand
  * Remove Spreadsheet::XLSX::Reader::LibXML test files from distribution
  * Allow old versions of Spreadsheet::ParseXLSX to "fail" on percentage tests
  0.65	- 15 Jun 2016, H.Merijn Brand
  * Test with perl-5.24.0
  * Show parser-version used under debug
  * No more Spreadsheet::XLSX::Reader::LibXML
  * Cells will inherit hidden state from hidden rows and columns
  * Require 5.8.0 as 5.6.x does not include required Encode
  0.64	- 22 Apr 2016, H.Merijn Brand
  * It's 2016
  * Allow inconsistent Spreadsheet::XLSX releases on Debian (tests)
  * Decode utf-16be entries in Excel when appropriate
  * Two examples in xlscat
  0.63	- 10 Oct 2015, H.Merijn Brand
  * Guard against negative MinRow in XLSX
  * Documentation updated
  * Support Spreadsheet::XLSX::Reader::LibXML disabled on author request
  * Fix warning in utilities
  * Check minimum parser version for pre-selected parser
  0.62	- 16 Aug 2015, H.Merijn Brand
  * Fix documentation structure
  * Test all supported parsers (not just the preferred one)
  * Basic support for Spreadsheet::XLSX::Reader::LibXML (work in progress)
  * Copy example file if link fails (Alan Berndt)
  * Add a contributing guide
  0.61	- 13 Jun 2015, H.Merijn Brand
  * Discourage Spreadsheet::XLSX
  * A space is not an empty field in XLS
  * Strip the correct selection (RT#105197)
  0.60	- 30 Mar 2015, H.Merijn Brand
  * No merged cell support in Spreadsheet::XLSX
  0.59	- 26 Mar 2015, H.Merijn Brand
  * Minimal support (+ docs) for merged cells
  * Make parser errors report at one level up
  * Don't select non-existing columns in xlscat
  0.58	- 11 Feb 2015, H.Merijn Brand
  * Remove perl recommendation from META as it breaks cpan clients
  * Move sort instruction to correct place in xlscat's help
  0.57	- 08 Feb 2015, H.Merijn Brand
  * Moved project to github
  * Add --sort to xlscat
  * Clip before conversion
  * Removed an unneeded localizing of $/ (related to p5 RT#123218)
  0.56	- 05 Jan 2015, H.Merijn Brand
  * printf does not play nice with encoding (related to RT#98436)
  * default output UTF-8 if whole line is UTF-8
  0.55	- 01 Jan 2015, H.Merijn Brand
  * Mention Spreadsheet::CSV in documentation
  * Add ssdiff to examples
  * Amend xlscat -n to also number in HTML
  * Updated copyright to 2015
  0.54	- 30 Jan 2014, H.Merijn Brand
  * Optional features required versions now builtin
  0.53	- 29 Jan 2014, H.Merijn Brand
  * Updated copyright to 2014
  * Prefer Data::Peek over Data::Dumper
  * Support (and prefer) Spreadsheet::ParseXLSX for .xlsx
  0.52	- 05 Dec 2013, H.Merijn Brand
  * Store CSV parse error - if any - in $ss->[0]{error}
  0.51	- 30 Oct 2013, H.Merijn Brand
  * Link xlsgrep during install
  0.50	- 24 Oct 2013, H.Merijn Brand
  * Added xlsgrep to examples
  * Allow -C B,D for xlscat
  * More prominent reference to xlscat in docs
* Sat Jun 15 2013 coolo@suse.com
- obsolete xsl2csv
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.49
  * /dev/null cannot be used for tests on Windows
  * Improve documentation consistency (RT#80409)
  * Updated copyright to 2013
  * Force old(er) tar format (ustar) - assumes GNU tar on release box
  * Fix yml/json optional_features
  * Install utilities from example by default
  * Several minor changes (for maint)
  * Note that empty sheets are skipped when clip is true (RT#75277)
  * Allow undef as valid value for the options (Max Maischein)
  * Don't generate warnings when stripping whitespace and only
    generating one of cells or rc. (Max Maschein)
  * Fix test warning under perl-5.17.x
* Fri Feb 17 2012 coolo@suse.com
- updated to 0.46
  * Updated copyright to 2012
  * Support passing attributes to the underlying parser
  * Do not strip fields in sheets with no cells at all (RT#74976)
* Fri Nov 18 2011 coolo@suse.com
- update to 0.45
  - NAME / DISTNAME in Makefile.PL
  - More cross-checks for META data
* Thu Sep  1 2011 chris@computersalat.de
- initial package 0.43
  * created by cpanspec 1.78.05
